==> maxscale-21.06.18-Source.tar.gz: maxscale-21.06.18-Source/maxctrl/lib/set.js <==
/*
 * Copyright (c) 2016 MariaDB Corporation Ab
 * Copyright (c) 2023 MariaDB plc, Finnish Branch
 *
 * Use of this software is governed by the Business Source License included
 * in the LICENSE.TXT file and at www.mariadb.com/bsl11.
 *
 * Change Date: 2024-06-03
 *
 * On the date above, in accordance with the Business Source License, use
 * of this software will be governed by version 2 or later of the General
 * Public License.
 */
require("./common.js")();

exports.command = "set <command>";
exports.desc = "Set object state";
exports.handler = function () {};
exports.builder = function (yargs) {
  yargs
    .group(["force"], "Set options:")
    .option("force", {
      describe: "If combined with the `maintenance` state, this forcefully closes all connections to the target server",
      type: "boolean",
      default: false,
    })
    .command(
      "server <server> <state>",
      "Set server state",
      function (yargs) {
        return yargs
          .epilog(
            "If <server> is monitored by a monitor, this command should " +
              "only be used to set the server into the `maintenance` or the `drain` state. " +
              "Any other states will be overridden by the monitor on the next " +
              "monitoring interval. To manually control server states, use the " +
              "`stop monitor <name>` command to stop the monitor before setting " +
              "the server states manually.\n" +
              "\n" +
              "When a server is set into the `drain` state, no new connections to " +
              "it are allowed but existing connections are allowed to gracefully close. " +
              "Servers with the `Master` status cannot be drained or " +
              "set into maintenance mode. To clear a state set by this command, use " +
              "the `clear server` command.\n" +
              "\n" +
              "To forcefully close all connections to a server, use `set server <name> maintenance --force`\n"
          )
          .usage("Usage: set server <server> <state>");
      },
      function (argv) {
        var target = "servers/" + argv.server + "/set?state=" + argv.state;
        if (argv.force) {
          target += "&force=yes";
        }
        maxctrl(argv, function (host) {
          return doRequest(host, target, { method: "PUT" });
        });
      }
    )
    .usage("Usage: set <command>")
    .help()
    .wrap(null)
    .demandCommand(1, helpMsg);
};

==> maxscale-22.08.15-Source.tar.gz: maxscale-22.08.15-Source/maxctrl/lib/set.js <==
/*
 * Copyright (c) 2016 MariaDB Corporation Ab
 * Copyright (c) 2023 MariaDB plc, Finnish Branch
 *
 * Use of this software is governed by the Business Source License included
 * in the LICENSE.TXT file and at www.mariadb.com/bsl11.
 *
 * Change Date: 2025-09-12
 *
 * On the date above, in accordance with the Business Source License, use
 * of this software will be governed by version 2 or later of the General
 * Public License.
 */
const { maxctrl, doRequest, helpMsg } = require("./common.js");

exports.command = "set <command>";
exports.desc = "Set object state";
exports.handler = function () {};
exports.builder = function (yargs) {
  yargs
    .group(["force"], "Set options:")
    .option("force", {
      describe:
        "If combined with the `maintenance` state, this forcefully closes all connections to the target server",
      type: "boolean",
      default: false,
    })
    .command(
      "server <server> <state...>",
      "Set server state",
      function (yargs) {
        return yargs
          .epilog(
            "If <server> is monitored by a monitor, this command should " +
              "only be used to set the server into the `maintenance` or the `drain` state. " +
              "Any other states will be overridden by the monitor on the next " +
              "monitoring interval. To manually control server states, use the " +
              "`stop monitor <name>` command to stop the monitor before setting " +
              "the server states manually.\n" +
              "\n" +
              "When a server is set into the `drain` state, no new connections to " +
              "it are allowed but existing connections are allowed to gracefully close. " +
              "Servers with the `Master` status cannot be drained or " +
              "set into maintenance mode. To clear a state set by this command, use " +
              "the `clear server` command.\n" +
              "\n" +
              "To forcefully close all connections to a server, use `set server <name> maintenance --force`\n"
          )
          .usage("Usage: set server <server> <state...>");
      },
      function (argv) {
        maxctrl(argv, function (host) {
          var target = "servers/" + argv.server + "/set?";
          if (argv.force) {
            target += "force=yes&";
          }

          return Promise.all(
            argv.state.map((state) => doRequest(host, target + "state=" + state, { method: "PUT" }))
          );
        });
      }
    )
    .usage("Usage: set <command>")
    .help()
    .wrap(null)
    .demandCommand(1, helpMsg);
};
